pub fn set_max_collators<T: Config>(max: Option<u32>)Expand description
Set the maximum number of validators returned as collators.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::set_max_collators.